@@ -12,7 +12,7 @@ class MongoObject(object):
     """
     def __init__(self, host, port, username, password, auth_db='admin'):
         self.insert_bench = 6000
-        self.client = MongoClient(f"mongodb://{host}:{port}")
+        self.client = MongoClient("mongodb://{}:{}".format(host, port))
         db = self.client[auth_db]
         db.authenticate(username, password)
 
@@ -152,3 +152,5 @@ class MongoObject(object):
         if cursor:
             docs = list(cursor)
             return pd.DataFrame(docs)
+
+
