@@ -533,34 +533,37 @@ class Postgres(object):
                                 host=conf['host'],
                                 port=int(conf['port']))
         cursor = conn.cursor()
+        df['update_time'] = datetime.now()
         cc = df.values.tolist()
+        columns_raw = df.columns.tolist()
+        columns = ['"{}"'.format(i) for i in columns_raw]
         str_list = []
         for c in cc:
             str_list.append(','.join([str(i) for i in c]))
         string = '\n'.join(str_list)
-        columns = df.columns.tolist()
         f = StringIO()  # StringIO 结构类似文件，但是内容都在内存里面
         # 循环写入数据到内存里面， 里面每个字段用制表符\t 隔开，每一行用换行符\n 隔开
         f.write(string)
-
-        # 最重要的一步，要把f 的游标移到第一位，write 方法后，游标会变成最尾，StringIO(**) 就不会
         f.seek(0)
         if not self.is_table_exist(table_name):
             sql_list = []
-            print(columns)
-            for dd in columns:
+            for dd in columns_raw:
                 if dd in date_columns:
-                    ddd = '{dd} date'.format(dd)
+                    ddd = '"{}" date'.format(dd)
                 elif dd in text_column:
-                    ddd = '{} text'.format(dd)
+                    ddd = '"{}" text'.format(dd)
+                elif dd == 'update_time':
+                    ddd = '"update_time" timestamp'
                 else:
-                    ddd = '{} float'.format(dd)
+                    ddd = '"{}" float'.format(dd)
                 sql_list.append(ddd)
             sql_str = ','.join(sql_list)
-            cursor.execute('create table {} ({});'.format(table_name, sql_str))
+            sql = 'create table {} ({});'.format(table_name, sql_str)
+            cursor.execute(sql)
+            logger.info(sql)
         cursor.copy_from(f, table_name,
                          columns=columns,
-                         sep=',', null='', size=16384)  # 默认sep和null 都是none
+                         sep=',', null='', size=16384) 
 
         conn.commit()
         cursor.close()
